@@ -107,7 +107,7 @@ except ImportError:
                           " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.4.1'
+__version__ = '2.4.2'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^\n]*?)(\s+#\s*([^\n]*)|$)')
@@ -141,6 +141,7 @@ S_INFO = [
 # Detect Python3 and which OS for temperments.
 PY3 = platform.python_version()[0] == '3'
 WINOS = platform.system() == 'Windows'
+POSIX = os.name == 'posix'
 SYSTEMV = not WINOS and os.uname()[0] in ["SunOS", "AIX", "HP-UX"]
 SYSTEMV = not WINOS and (
     os.uname()[0] in ["SunOS", "AIX", "HP-UX"]
@@ -176,7 +177,7 @@ def open_pipe(cmd, *args, **flags):
 
     a. keyword args are flags and always appear /before/ arguments for bsd
     """
-    cmd_args = tuple(shlex.split(cmd))
+    cmd_args = tuple(shlex.split(cmd, posix=flags.pop('posix', POSIX)))
     env = flags.pop('env', None)
     for (key, value) in flags.items():
         if len(key) == 1:
@@ -226,7 +227,7 @@ class CronTab(object):
         self.intab = tab
         self.read(tabfile)
         self._log = log
-    
+
     def __enter__(self):
         return self
 
